@@ -22,7 +22,6 @@ from keystoneauth1.identity import generic
 from keystoneauth1 import session as kssession
 from oslo_utils import encodeutils
 from oslo_utils import importutils
-import six
 
 import heatclient
 from heatclient._i18n import _
@@ -33,7 +32,7 @@ from heatclient import exc
 osprofiler_profiler = importutils.try_import("osprofiler.profiler")
 
 
-class HeatShell(object):
+class HeatShell:
 
     def _append_global_identity_args(self, parser):
         # FIXME(gyee): these are global identity (Keystone) arguments which
@@ -593,8 +592,8 @@ class HeatShell(object):
 class HelpFormatter(argparse.HelpFormatter):
     def start_section(self, heading):
         # Title-case the headings
-        heading = '%s%s' % (heading[0].upper(), heading[1:])
-        super(HelpFormatter, self).start_section(heading)
+        heading = f'{heading[0].upper()}{heading[1:]}'
+        super().start_section(heading)
 
 
 def main(args=None):
@@ -610,7 +609,7 @@ def main(args=None):
         if '--debug' in args or '-d' in args:
             raise
         else:
-            print(encodeutils.safe_encode(six.text_type(e)), file=sys.stderr)
+            print(encodeutils.safe_encode(str(e)), file=sys.stderr)
         sys.exit(1)
 
 
