@@ -122,21 +122,21 @@ class ShellTest(testtools.TestCase):
 
     def test_resource_nested_identifier(self):
         rsrc_info = {'resource_name': 'aresource',
-                     'links': [{'href': u'http://foo/name/id/resources/0',
-                                'rel': u'self'},
-                               {'href': u'http://foo/name/id',
-                                'rel': u'stack'},
-                               {'href': u'http://foo/n_name/n_id',
-                                'rel': u'nested'}]}
+                     'links': [{'href': 'http://foo/name/id/resources/0',
+                                'rel': 'self'},
+                               {'href': 'http://foo/name/id',
+                                'rel': 'stack'},
+                               {'href': 'http://foo/n_name/n_id',
+                                'rel': 'nested'}]}
         rsrc = hc_res.Resource(manager=None, info=rsrc_info)
         self.assertEqual('n_name/n_id', utils.resource_nested_identifier(rsrc))
 
     def test_resource_nested_identifier_none(self):
         rsrc_info = {'resource_name': 'aresource',
-                     'links': [{'href': u'http://foo/name/id/resources/0',
-                                'rel': u'self'},
-                               {'href': u'http://foo/name/id',
-                                'rel': u'stack'}]}
+                     'links': [{'href': 'http://foo/name/id/resources/0',
+                                'rel': 'self'},
+                               {'href': 'http://foo/name/id',
+                                'rel': 'stack'}]}
         rsrc = hc_res.Resource(manager=None, info=rsrc_info)
         self.assertIsNone(utils.resource_nested_identifier(rsrc))
 
@@ -145,8 +145,8 @@ class ShellTest(testtools.TestCase):
         self.assertEqual('{}', utils.json_formatter({}))
         self.assertEqual('{\n  "foo": "bar"\n}',
                          utils.json_formatter({"foo": "bar"}))
-        self.assertEqual(u'{\n  "Uni": "test\u2665"\n}',
-                         utils.json_formatter({"Uni": u"test\u2665"}))
+        self.assertEqual('{\n  "Uni": "test\u2665"\n}',
+                         utils.json_formatter({"Uni": "test\u2665"}))
 
     def test_yaml_formatter(self):
         self.assertEqual('null\n...\n', utils.yaml_formatter(None))
@@ -162,8 +162,8 @@ class ShellTest(testtools.TestCase):
         self.assertEqual(
             'one two three four five six seven eight nine ten eleven\ntwelve',
             utils.text_wrap_formatter(
-                ('one two three four five six seven '
-                 'eight nine ten eleven twelve')))
+                'one two three four five six seven '
+                'eight nine ten eleven twelve'))
 
     def test_newline_list_formatter(self):
         self.assertEqual('', utils.newline_list_formatter(None))
@@ -380,14 +380,15 @@ class ShellTestParameterFiles(testtools.TestCase):
 class TestURLFunctions(testtools.TestCase):
 
     def setUp(self):
-        super(TestURLFunctions, self).setUp()
+        super().setUp()
         self.m = mock.MagicMock()
 
         self.addCleanup(self.m.UnsetStubs)
 
     def test_normalise_file_path_to_url_relative(self):
+        from pathlib import Path
         self.assertEqual(
-            'file://' + request.pathname2url('%s/foo' % os.getcwd()),
+            Path('%s/foo' % os.getcwd()).as_uri(),
             utils.normalise_file_path_to_url(
                 'foo'))
 
